======
Erin
======

This is the documentation of **Erin**.


Contents
========

.. toctree::
   :maxdepth: 2

   License <license>
   Authors <authors>
   Contribution Guidelines <contributing>
   Installation <installation/index>
   User Manual <manual/index>
   Developer Handbook <handbook/index>
   Module Reference <api/modules>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
